==> nextcloud-20.0.13.tgz: nextcloud/apps/user_status/l10n/fi.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Viimeisimmät tilatiedot",
    "In a meeting" : "Tapaamisessa",
    "Commuting" : "Työmatkalla",
    "Out sick" : "Sairaana",
    "Vacationing" : "Lomailemassa",
    "Working remotely" : "Etätyössä",
    "User status" : "Käyttäjän tilatieto",
    "Clear status message after" : "Tyhjennä tilaviesti, kun on kulunut",
    "Set status" : "Aseta tilatieto",
    "Online status" : "Online-tila",
    "Status message" : "Tilaviesti",
    "Clear status message" : "Tyhjennä tilaviesti",
    "Set status message" : "Aseta tilaviesti",
    "There was an error saving the status" : "Tilatiedon tallentamisessa tapahtui virhe",
    "There was an error clearing the status" : "Tilatietoa tyhjentäessä tapahtui virhe",
    "No recent status changes" : "Ei viimeisimpiä tilatietomuutoksia",
    "Away" : "Poissa",
    "Do not disturb" : "Älä häiritse",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Älä tyhjennä",
    "Today" : "Tänään",
    "This week" : "Tällä viikolla",
    "Online" : "Paikalla",
    "Invisible" : "Näkymätön",
    "Offline" : "Poissa",
    "There was an error saving the new status" : "Uuden tilatiedon tallentamisessa tapahtui virhe",
    "30 minutes" : "30 minuuttia",
    "1 hour" : "1 tunti",
    "4 hours" : "4 tuntia",
    "Mute all notifications" : "Mykistä kaikki ilmoitukset",
    "Appear offline" : "Näytä olevan poissa",
    "Clear status after" : "Tyhjennä tilatieto",
    "What's your status?" : "Mikä on tilatietosi?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.4.tgz: nextcloud/apps/user_status/l10n/fi.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Viimeisimmät tilatiedot",
    "In a meeting" : "Tapaamisessa",
    "Commuting" : "Työmatkalla",
    "Out sick" : "Sairaana",
    "Vacationing" : "Lomailemassa",
    "Working remotely" : "Etätyössä",
    "User status" : "Käyttäjän tilatieto",
    "Clear status message after" : "Tyhjennä tilaviesti, kun on kulunut",
    "What's your status?" : "Mikä on tilatietosi?",
    "Set status" : "Aseta tilatieto",
    "Online status" : "Online-tila",
    "Status message" : "Tilaviesti",
    "Clear status message" : "Tyhjennä tilaviesti",
    "Set status message" : "Aseta tilaviesti",
    "There was an error saving the status" : "Tilatiedon tallentamisessa tapahtui virhe",
    "There was an error clearing the status" : "Tilatietoa tyhjentäessä tapahtui virhe",
    "No recent status changes" : "Ei viimeisimpiä tilatietomuutoksia",
    "Away" : "Poissa",
    "Do not disturb" : "Älä häiritse",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Älä tyhjennä",
    "Today" : "Tänään",
    "This week" : "Tällä viikolla",
    "Online" : "Paikalla",
    "Invisible" : "Näkymätön",
    "Offline" : "Poissa",
    "There was an error saving the new status" : "Uuden tilatiedon tallentamisessa tapahtui virhe",
    "30 minutes" : "30 minuuttia",
    "1 hour" : "1 tunti",
    "4 hours" : "4 tuntia",
    "Mute all notifications" : "Mykistä kaikki ilmoitukset",
    "Appear offline" : "Näytä olevan poissa",
    "Clear status after" : "Tyhjennä tilatieto"
},
"nplurals=2; plural=(n != 1);");
